@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
-  You may not use this file except in compliance with the License.
+  You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
   
-    http://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,48 +15,15 @@
 
   MagickCore delegates methods.
 */
-#ifndef _MAGICKCORE_DELEGATE_H
-#define _MAGICKCORE_DELEGATE_H
+#ifndef MAGICKCORE_DELEGATE_H
+#define MAGICKCORE_DELEGATE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
-#if defined(HasGS)
-#include "ghostscript/iapi.h"
-#include "ghostscript/ierrors.h"
-#endif
-
-#ifndef gs_main_instance_DEFINED
-# define gs_main_instance_DEFINED
-typedef struct gs_main_instance_s gs_main_instance;
-#endif
-
-#if !defined(MagickDLLCall)
-#  if defined(__WINDOWS__)
-#    define MagickDLLCall __stdcall
-#  else
-#    define MagickDLLCall
-#  endif
-#endif
-
-typedef struct _GhostscriptVectors
-{
-  int
-    (MagickDLLCall *exit)(gs_main_instance *);
-
-  int
-    (MagickDLLCall *init_with_args)(gs_main_instance *,int,char **);
-
-  int
-    (MagickDLLCall *new_instance)(gs_main_instance **,void *);
-
-  int
-    (MagickDLLCall *run_string)(gs_main_instance *,const char *,int,int *);
-
-  void
-    (MagickDLLCall *delete_instance)(gs_main_instance *);
-} GhostscriptVectors;
+#include <stdarg.h>
+#include "magick/semaphore.h"
 
 typedef struct _DelegateInfo
 {
@@ -65,45 +32,53 @@ typedef struct _DelegateInfo
     *decode,
     *encode,
     *commands;
-                                                                                
-  long
+
+  ssize_t
     mode;
-                                                                                
+
   MagickBooleanType
     thread_support,
     spawn,
     stealth;
-                                                                                
+
   struct _DelegateInfo
     *previous,
     *next;  /* deprecated, use GetDelegateInfoList() */
 
-  unsigned long
+  size_t
     signature;
+
+  SemaphoreInfo
+    *semaphore;
 } DelegateInfo;
 
 extern MagickExport char
   *GetDelegateCommand(const ImageInfo *,Image *,const char *,const char *,
     ExceptionInfo *),
-  **GetDelegateList(const char *,unsigned long *,ExceptionInfo *);
+  **GetDelegateList(const char *,size_t *,ExceptionInfo *);
 
 extern MagickExport const char
   *GetDelegateCommands(const DelegateInfo *);
 
 extern MagickExport const DelegateInfo
   *GetDelegateInfo(const char *,const char *,ExceptionInfo *exception),
-  **GetDelegateInfoList(const char *,unsigned long *,ExceptionInfo *);
+  **GetDelegateInfoList(const char *,size_t *,ExceptionInfo *);
 
-extern MagickExport long
+extern MagickExport int
+  ExternalDelegateCommand(const MagickBooleanType,const MagickBooleanType,
+    const char *,char *,ExceptionInfo *);
+
+extern MagickExport ssize_t
   GetDelegateMode(const DelegateInfo *);
 
 extern MagickExport MagickBooleanType
+  DelegateComponentGenesis(void),
   GetDelegateThreadSupport(const DelegateInfo *),
   InvokeDelegate(ImageInfo *,Image *,const char *,const char *,ExceptionInfo *),
   ListDelegateInfo(FILE *,ExceptionInfo *);
 
 extern MagickExport void
-  DestroyDelegateList(void);
+  DelegateComponentTerminus(void);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
